@@ -43,6 +43,7 @@ func ExampleExample() {
 	//   "mode": "fix",
 	//   "lint": "fix",
 	//   "warningsList": [
+	//     "allowed-symbol-load-locations",
 	//     "attr-applicable_licenses",
 	//     "attr-cfg",
 	//     "attr-license",
@@ -52,6 +53,7 @@ func ExampleExample() {
 	//     "attr-single-file",
 	//     "build-args-kwargs",
 	//     "bzl-visibility",
+	//     "canonical-repository",
 	//     "confusing-name",
 	//     "constant-glob",
 	//     "ctx-actions",
@@ -63,6 +65,7 @@ func ExampleExample() {
 	//     "dict-concatenation",
 	//     "dict-method-named-arg",
 	//     "duplicated-name",
+	//     "external-path",
 	//     "filetype",
 	//     "function-docstring",
 	//     "function-docstring-args",
@@ -261,6 +264,7 @@ func TestValidate(t *testing.T) {
 		"type auto":             {options: "--type=auto"},
 		"type error":            {options: "--type=foo", wantErr: fmt.Errorf("unrecognized input type foo; valid types are build, bzl, workspace, default, module, auto")},
 		"warnings all": {options: "--warnings=all", wantWarnings: []string{
+			"allowed-symbol-load-locations",
 			"attr-applicable_licenses",
 			"attr-cfg",
 			"attr-license",
@@ -270,6 +274,7 @@ func TestValidate(t *testing.T) {
 			"attr-single-file",
 			"build-args-kwargs",
 			"bzl-visibility",
+			"canonical-repository",
 			"confusing-name",
 			"constant-glob",
 			"ctx-actions",
@@ -281,6 +286,7 @@ func TestValidate(t *testing.T) {
 			"dict-concatenation",
 			"dict-method-named-arg",
 			"duplicated-name",
+			"external-path",
 			"filetype",
 			"function-docstring",
 			"function-docstring-args",
@@ -360,6 +366,7 @@ func TestValidate(t *testing.T) {
 			"unused-variable",
 		}},
 		"warnings default": {options: "--warnings=default", wantWarnings: []string{
+			"allowed-symbol-load-locations",
 			"attr-applicable_licenses",
 			"attr-cfg",
 			"attr-license",
@@ -369,6 +376,7 @@ func TestValidate(t *testing.T) {
 			"attr-single-file",
 			"build-args-kwargs",
 			"bzl-visibility",
+			"canonical-repository",
 			"confusing-name",
 			"constant-glob",
 			"ctx-actions",
@@ -380,6 +388,7 @@ func TestValidate(t *testing.T) {
 			"dict-concatenation",
 			"dict-method-named-arg",
 			"duplicated-name",
+			"external-path",
 			"filetype",
 			"function-docstring",
 			"function-docstring-args",
@@ -459,6 +468,7 @@ func TestValidate(t *testing.T) {
 			"unused-variable",
 		}},
 		"warnings plus/minus": {options: "--warnings=+unsorted-dict-items,-print,-deprecated-function", wantWarnings: []string{
+			"allowed-symbol-load-locations",
 			"attr-applicable_licenses",
 			"attr-cfg",
 			"attr-license",
@@ -468,6 +478,7 @@ func TestValidate(t *testing.T) {
 			"attr-single-file",
 			"build-args-kwargs",
 			"bzl-visibility",
+			"canonical-repository",
 			"confusing-name",
 			"constant-glob",
 			"ctx-actions",
@@ -479,6 +490,7 @@ func TestValidate(t *testing.T) {
 			"dict-concatenation",
 			"dict-method-named-arg",
 			"duplicated-name",
+			"external-path",
 			"filetype",
 			"function-docstring",
 			"function-docstring-args",
@@ -548,7 +560,108 @@ func TestValidate(t *testing.T) {
 			"repository-name",
 			"return-value",
 			"rule-impl-return",
-
+			"skylark-comment",
+			"skylark-docstring",
+			"string-iteration",
+			"uninitialized",
+			"unnamed-macro",
+			"unreachable",
+			"unsorted-dict-items",
+			"unused-variable",
+		}},
+		"warnings no duplicates": {options: "--warnings=+unused-variable", wantWarnings: []string{
+			"allowed-symbol-load-locations",
+			"attr-applicable_licenses",
+			"attr-cfg",
+			"attr-license",
+			"attr-licenses",
+			"attr-non-empty",
+			"attr-output-default",
+			"attr-single-file",
+			"build-args-kwargs",
+			"bzl-visibility",
+			"canonical-repository",
+			"confusing-name",
+			"constant-glob",
+			"ctx-actions",
+			"ctx-args",
+			"deprecated-function",
+			"depset-items",
+			"depset-iteration",
+			"depset-union",
+			"dict-concatenation",
+			"dict-method-named-arg",
+			"duplicated-name",
+			"external-path",
+			"filetype",
+			"function-docstring",
+			"function-docstring-args",
+			"function-docstring-header",
+			"function-docstring-return",
+			"git-repository",
+			"http-archive",
+			"integer-division",
+			"keyword-positional-params",
+			"list-append",
+			"load",
+			"module-docstring",
+			"name-conventions",
+			"native-android",
+			"native-build",
+			"native-cc-binary",
+			"native-cc-common",
+			"native-cc-debug-package-info",
+			"native-cc-fdo-prefetch-hints",
+			"native-cc-fdo-profile",
+			"native-cc-import",
+			"native-cc-info",
+			"native-cc-library",
+			"native-cc-memprof-profile",
+			"native-cc-objc-import",
+			"native-cc-objc-library",
+			"native-cc-propeller-optimize",
+			"native-cc-proto",
+			"native-cc-shared-library",
+			"native-cc-shared-library-hint-info",
+			"native-cc-shared-library-info",
+			"native-cc-test",
+			"native-cc-toolchain",
+			"native-cc-toolchain-suite",
+			"native-java-binary",
+			"native-java-common",
+			"native-java-import",
+			"native-java-info",
+			"native-java-library",
+			"native-java-lite-proto",
+			"native-java-package-config",
+			"native-java-plugin",
+			"native-java-plugin-info",
+			"native-java-proto",
+			"native-java-runtime",
+			"native-java-test",
+			"native-java-toolchain",
+			"native-package",
+			"native-proto",
+			"native-proto-common",
+			"native-proto-info",
+			"native-proto-lang-toolchain",
+			"native-proto-lang-toolchain-info",
+			"native-py",
+			"native-sh-binary",
+			"native-sh-library",
+			"native-sh-test",
+			"no-effect",
+			"output-group",
+			"overly-nested-depset",
+			"package-name",
+			"package-on-top",
+			"positional-args",
+			"print",
+			"provider-params",
+			"redefined-variable",
+			"repository-name",
+			"return-value",
+			"rule-impl-return",
 			"skylark-comment",
 			"skylark-docstring",
 			"string-iteration",
@@ -556,7 +669,6 @@ func TestValidate(t *testing.T) {
 			"unnamed-macro",
 			"unreachable",
 			"unused-variable",
-			"unsorted-dict-items",
 		}},
 		"warnings error": {options: "--warnings=native-py,-print,-deprecated-function", wantErr: fmt.Errorf(`warning categories with modifiers ("+" or "-") can't be mixed with raw warning categories`)},
 	} {
