@@ -112,66 +112,67 @@ func makeLinterFinding(node build.Expr, message string, replacement ...LinterRep
 
 // RuleWarningMap lists the warnings that run on a single rule.
 // These warnings run only on BUILD files (not bzl files).
-var RuleWarningMap = map[string]func(call *build.CallExpr, pkg string) *LinterFinding{
-	"positional-args": positionalArgumentsWarning,
-}
+var RuleWarningMap = map[string]func(call *build.CallExpr, pkg string) *LinterFinding{}
 
 // FileWarningMap lists the warnings that run on the whole file.
 var FileWarningMap = map[string]func(f *build.File) []*LinterFinding{
-	"attr-applicable_licenses":  attrApplicableLicensesWarning,
-	"attr-cfg":                  attrConfigurationWarning,
-	"attr-license":              attrLicenseWarning,
-	"attr-licenses":             attrLicensesWarning,
-	"attr-non-empty":            attrNonEmptyWarning,
-	"attr-output-default":       attrOutputDefaultWarning,
-	"attr-single-file":          attrSingleFileWarning,
-	"build-args-kwargs":         argsKwargsInBuildFilesWarning,
-	"bzl-visibility":            bzlVisibilityWarning,
-	"confusing-name":            confusingNameWarning,
-	"constant-glob":             constantGlobWarning,
-	"ctx-actions":               ctxActionsWarning,
-	"ctx-args":                  contextArgsAPIWarning,
-	"depset-items":              depsetItemsWarning,
-	"depset-iteration":          depsetIterationWarning,
-	"depset-union":              depsetUnionWarning,
-	"dict-method-named-arg":     dictMethodNamedArgWarning,
-	"dict-concatenation":        dictionaryConcatenationWarning,
-	"duplicated-name":           duplicatedNameWarning,
-	"filetype":                  fileTypeWarning,
-	"function-docstring":        functionDocstringWarning,
-	"function-docstring-header": functionDocstringHeaderWarning,
-	"function-docstring-args":   functionDocstringArgsWarning,
-	"function-docstring-return": functionDocstringReturnWarning,
-	"integer-division":          integerDivisionWarning,
-	"keyword-positional-params": keywordPositionalParametersWarning,
-	"list-append":               listAppendWarning,
-	"load":                      unusedLoadWarning,
-	"module-docstring":          moduleDocstringWarning,
-	"name-conventions":          nameConventionsWarning,
-	"native-build":              nativeInBuildFilesWarning,
-	"native-package":            nativePackageWarning,
-	"no-effect":                 noEffectWarning,
-	"output-group":              outputGroupWarning,
-	"overly-nested-depset":      overlyNestedDepsetWarning,
-	"package-name":              packageNameWarning,
-	"package-on-top":            packageOnTopWarning,
-	"print":                     printWarning,
-	"provider-params":           providerParamsWarning,
-	"redefined-variable":        redefinedVariableWarning,
-	"repository-name":           repositoryNameWarning,
-	"rule-impl-return":          ruleImplReturnWarning,
-	"return-value":              missingReturnValueWarning,
-	"skylark-comment":           skylarkCommentWarning,
-	"skylark-docstring":         skylarkDocstringWarning,
-	"string-iteration":          stringIterationWarning,
-	"uninitialized":             uninitializedVariableWarning,
-	"unreachable":               unreachableStatementWarning,
-	"unsorted-dict-items":       unsortedDictItemsWarning,
-	"unused-variable":           unusedVariableWarning,
+	"allowed-symbol-load-locations": symbolLoadLocationWarning,
+	"attr-applicable_licenses":      attrApplicableLicensesWarning,
+	"attr-cfg":                      attrConfigurationWarning,
+	"attr-license":                  attrLicenseWarning,
+	"attr-licenses":                 attrLicensesWarning,
+	"attr-non-empty":                attrNonEmptyWarning,
+	"attr-output-default":           attrOutputDefaultWarning,
+	"attr-single-file":              attrSingleFileWarning,
+	"build-args-kwargs":             argsKwargsInBuildFilesWarning,
+	"canonical-repository":          canonicalRepositoryWarning,
+	"confusing-name":                confusingNameWarning,
+	"constant-glob":                 constantGlobWarning,
+	"ctx-actions":                   ctxActionsWarning,
+	"ctx-args":                      contextArgsAPIWarning,
+	"depset-items":                  depsetItemsWarning,
+	"depset-iteration":              depsetIterationWarning,
+	"depset-union":                  depsetUnionWarning,
+	"dict-method-named-arg":         dictMethodNamedArgWarning,
+	"dict-concatenation":            dictionaryConcatenationWarning,
+	"duplicated-name":               duplicatedNameWarning,
+	"external-path":                 externalPathWarning,
+	"filetype":                      fileTypeWarning,
+	"function-docstring":            functionDocstringWarning,
+	"function-docstring-header":     functionDocstringHeaderWarning,
+	"function-docstring-args":       functionDocstringArgsWarning,
+	"function-docstring-return":     functionDocstringReturnWarning,
+	"integer-division":              integerDivisionWarning,
+	"keyword-positional-params":     keywordPositionalParametersWarning,
+	"list-append":                   listAppendWarning,
+	"load":                          unusedLoadWarning,
+	"module-docstring":              moduleDocstringWarning,
+	"name-conventions":              nameConventionsWarning,
+	"native-build":                  nativeInBuildFilesWarning,
+	"native-package":                nativePackageWarning,
+	"no-effect":                     noEffectWarning,
+	"output-group":                  outputGroupWarning,
+	"overly-nested-depset":          overlyNestedDepsetWarning,
+	"package-name":                  packageNameWarning,
+	"package-on-top":                packageOnTopWarning,
+	"print":                         printWarning,
+	"provider-params":               providerParamsWarning,
+	"redefined-variable":            redefinedVariableWarning,
+	"repository-name":               repositoryNameWarning,
+	"rule-impl-return":              ruleImplReturnWarning,
+	"return-value":                  missingReturnValueWarning,
+	"skylark-comment":               skylarkCommentWarning,
+	"skylark-docstring":             skylarkDocstringWarning,
+	"string-iteration":              stringIterationWarning,
+	"uninitialized":                 uninitializedVariableWarning,
+	"unreachable":                   unreachableStatementWarning,
+	"unsorted-dict-items":           unsortedDictItemsWarning,
+	"unused-variable":               unusedVariableWarning,
 }
 
 // MultiFileWarningMap lists the warnings that run on the whole file, but may use other files.
 var MultiFileWarningMap = map[string]func(f *build.File, fileReader *FileReader) []*LinterFinding{
+	"bzl-visibility":                     bzlVisibilityWarning,
 	"deprecated-function":                deprecatedFunctionWarning,
 	"git-repository":                     nativeGitRepositoryWarning,
 	"http-archive":                       nativeHTTPArchiveWarning,
@@ -217,6 +218,7 @@ var MultiFileWarningMap = map[string]func(f *build.File, fileReader *FileReader)
 	"native-sh-binary":                   NativeShellRulesWarning("sh_binary"),
 	"native-sh-library":                  NativeShellRulesWarning("sh_library"),
 	"native-sh-test":                     NativeShellRulesWarning("sh_test"),
+	"positional-args":                    positionalArgumentsWarning,
 	"unnamed-macro":                      unnamedMacroWarning,
 }
 
